Crate vapcore_builtin[−][src]
Standard built-in contracts.
Structs
| AltBn128ConstOperations | Pricing for constant alt_bn128 operations (ECADD and ECMUL) |
| Blake2F | The Blake2F builtin |
| Bn128Add | The Bn128Add builtin |
| Bn128Mul | The Bn128Mul builtin |
| Bn128Pairing | The Bn128Pairing builtin |
| Builtin | Pricing scheme, execution definition, and activation block for a built-in contract. |
| EcRecover | The EC Recover builtin |
| Identity | The identity builtin |
| Modexp | The Modexp builtin |
| Ripemd160 | The Ripemd160 builtin |
| Sha256 | The Sha256 builtin |
Traits
| Implementation | Native implementation of a built-in contract. |
Type Definitions
| Blake2FPricer | Pricing for the Blake2 compression function (aka “F”). Computes the price as a fixed cost per round where the number of rounds is part of the input byte slice. |